<?php
/*
Plugin Name: Tag Dropdown Widget
Plugin URI: http://www.ethitter.com/plugins/tag-dropdown-widget/
Description: Creates a dropdown list of tags as an alternative to the tag cloud. Widget provides options to specify dropdown label, trim long tag names to fit theme constraints, display post counts, and exclude specific tags. Dropdown function can also be called directly for use in non-widget themes using <code>&lt;?php if(function_exists('makeTagDropdown')) {echo makeTagDropdown('x');} ?&gt;</code> where x represents the maximum tag length.
Author: Erick Hitter
Version: 1.6
Author URI: http://www.ethitter.com/
*/

add_action("plugins_loaded","Tag_Dropdown_pluginsloaded");

function Tag_Dropdown_pluginsloaded() {
	register_sidebar_widget("Tag Dropdown Widget","widget_TagDropdown");    
	register_widget_control("Tag Dropdown Widget","TagDropdown_control"); 
	register_deactivation_hook( __FILE__,"TagDropdown_deactivate");
	$foption = get_option("function_TagDropdown");if (!is_array($foption)) {$foption = array('do' => '0', 'limit' => '0');}
	$opt_exclude = get_option("widget_TagDropdown_exclude","notset"); if ($opt_exclude=="notset") {update_option("widget_TagDropdown_exclude","");}
}

function makeTagDropdown_do() {

$switch = get_option("TDW_direct");
switch ($switch["invoke"]) {

default:
case "default":

$options = get_option("widget_TagDropdown");
$limit = $options["limit"];
$exclude_array = get_option("widget_TagDropdown_exclude");

break;

case "direct":
	$options = get_option("TDW_direct");
	$limit = $options["limit"];
	$exclude_array = $options["exclude"];
break;
}

$exclude = explode(",", $exclude_array);

$tags = get_tags();
$tags_count = count($tags);

for ($i = 0;$i < $tags_count;$i++):
$slug = $tags[$i]->slug;
	if ($options["count"]=="on") {$count = " (".number_format_i18n($tags[$i]->count).")";}
	if (in_array($slug,$exclude)) {continue;}
	else {
		if ($limit>0) {if(strlen($tags[$i]->name)>$limit) {$name=substr($tags[$i]->name,0,$limit)."...";} else {$name=substr($tags[$i]->name,0,$limit);}} else {$name=$tags[$i]->name;}
		$tag_list .= '<option value="'. get_tag_link($tags[$i]->term_id) . '">' . $name. $count .'</option>';
	}
endfor;

$dropdown = "<!-- Tags dropdown by Tag Dropdown Widget - http://www.ethitter.com/plugins/tag-dropdown-widget/ -->";
$dropdown .= "<select name=\"archive-dropdown\" onchange=\"document.location.href=this.options[this.selectedIndex].value;\"><option value=\"\" selected=\"selected\">Select Tag</option>";
$dropdown .= $tag_list;
$dropdown .= "</select>";

echo $dropdown;

$options["invoke"] = "default"; update_option("TDW_direct", $options["invoke"]);
}

function makeTagDropdown($limit) {
$foption['limit'] = $limit;
$foption['do'] = "1";
update_option("function_TagDropdown", $foption);
makeTagDropdown_do();
}

function TDW_direct($limit,$count,$exclude) {
	$direct["invoke"] = "direct";
	$direct["limit"] = $limit;
	$direct["count"] = $count;
	$direct["exclude"] = $exclude;

update_option("TDW_direct",$direct);
makeTagDropdown_do();
}

function widget_TagDropdown($args) {
extract($args);
$options = get_option("widget_TagDropdown");
if (empty($options['title'])) {$title="Tags";} else {$title=$options['title'];}

echo $before_widget;
echo $before_title;
echo $title;
echo $after_title;
makeTagDropdown_do();
echo $after_widget;
}

function TagDropdown_control() {
	$options = get_option("widget_TagDropdown");
	if (!is_array($options)) {$options = array('title' => 'Tags', 'limit' => '0');}
	$opt_exclude = get_option("widget_TagDropdown_exclude");

if ($_POST["TagDropdown-Submit"]) {
	$options["title"] = htmlspecialchars($_POST["TagDropdown-Title"]);
	if (is_numeric($_POST["TagDropdown-Limit"])) {$options["limit"] = $_POST["TagDropdown-Limit"];} else {$options["limit"] = "0";}
	$options["count"] = $_POST["TagDropdown-Count"];
	$opt_exclude = $_POST["TagDropdown-exclude"];

update_option("widget_TagDropdown", $options);
update_option("widget_TagDropdown_exclude", $opt_exclude);
}

?>
<p>
<label for="TagDropdown-Title">Label: </label><br />
<input class="widefat" type="text" id="TagDropdown-Title" name="TagDropdown-Title" value="<?php echo $options['title'];?>" />
<br /><small><em>(Leave blank for default label.)</em></small><br /><br />
<label for="TagDropdown-Limit">Trim Long Tag Names to <em>x</em> Characters: </label>
<input type="text" id="TagDropdown-Limit" name="TagDropdown-Limit" size="3" maxlength="2" value="<?php echo $options['limit'];?>" />
<br /><small><em>(Set to 0 to display complete tags. Trim length does not consider post counts.)</em></small><br /><br />
<input type="checkbox" id="TagDropdown-Count" name="TagDropdown-Count"<?php if($options["count"]=="on") {echo " checked";}?>> <label for="TagDropdown-Count">Show post counts?</label><br /><br />
<label for="TagDropdown-exclude">Exclude tags:</label><br />
<input class="widefat" type="text" id="TagDropdown-exclude" name="TagDropdown-exclude" value="<?php echo $opt_exclude; ?>" />
<br /><small><em>Enter tag slugs, separated by commas, to exclude from the dropdown.</em></small>
<input type="hidden" id="TagDropdown-Submit" name="TagDropdown-Submit" value="1" />
<?php
}

function TagDropdown_deactivate() {
delete_option("widget_TagDropdown");
delete_option("widget_TagDropdown_exclude");
delete_option("function_TagDropdown");
delete_option("TDW_direct");
unregister_widget_control("TagDropdown_control");
unregister_sidebar_widget("widget_TagDropdown");
}

?>